@@ -1,5 +1,5 @@
 /* shishi.h --- Header file for Shishi library.                       -*- c -*-
- * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -29,7 +29,18 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.37"
+#define SHISHI_VERSION "0.0.38"
+
+# ifdef __cplusplus
+extern "C" {
+# endif
+
+#ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
+#  define __attribute__(Spec)	/* empty */
+# endif
+#endif
 
 /* Error codes */
 typedef enum
@@ -637,7 +648,7 @@ extern int shishi_init_server_with_paths (Shishi ** handle,
 					  const char *systemcfgfile);
 
 /* cfg.c */
-extern int shishi_cfg (Shishi * handle, char *option);
+extern int shishi_cfg (Shishi * handle, const char *option);
 extern int shishi_cfg_from_file (Shishi * handle, const char *cfg);
 extern int shishi_cfg_print (Shishi * handle, FILE * fh);
 extern const char *shishi_cfg_default_systemfile (Shishi * handle);
@@ -655,12 +666,16 @@ extern const char *shishi_strerror (int err);
 extern const char *shishi_error (Shishi * handle);
 extern void shishi_error_clear (Shishi * handle);
 extern void shishi_error_set (Shishi * handle, const char *errstr);
-extern void shishi_error_printf (Shishi * handle, const char *format, ...);
+extern void shishi_error_printf (Shishi * handle, const char *format, ...)
+  __attribute__ ((format (printf, 2, 3)));
 extern int shishi_error_outputtype (Shishi * handle);
 extern void shishi_error_set_outputtype (Shishi * handle, int type);
-extern void shishi_info (Shishi * handle, const char *format, ...);
-extern void shishi_warn (Shishi * handle, const char *format, ...);
-extern void shishi_verbose (Shishi * handle, const char *format, ...);
+extern void shishi_info (Shishi * handle, const char *format, ...)
+  __attribute__ ((format (printf, 2, 3)));
+extern void shishi_warn (Shishi * handle, const char *format, ...)
+  __attribute__ ((format (printf, 2, 3)));
+extern void shishi_verbose (Shishi * handle, const char *format, ...)
+  __attribute__ ((format (printf, 2, 3)));
 
 /* realm.c */
 extern char *shishi_realm_default_guess (void);
@@ -895,16 +910,8 @@ extern int shishi_ticket_save (Shishi * handle, FILE * fh,
 			       Shishi_asn1 ticket);
 extern int shishi_ticket_print (Shishi * handle, FILE * fh,
 				Shishi_asn1 ticket);
-extern int shishi_kdcreq_print (Shishi * handle, FILE * fh,
-				Shishi_asn1 kdcreq);
-extern int shishi_kdcrep_print (Shishi * handle, FILE * fh,
-				Shishi_asn1 kdcrep);
 extern int shishi_kdc_print (Shishi * handle, FILE * fh, Shishi_asn1 asreq,
 			     Shishi_asn1 asrep, Shishi_asn1 encasreppart);
-extern int shishi_kdcreq_parse (Shishi * handle, FILE * fh,
-				Shishi_asn1 * kdcreq);
-extern int shishi_kdcrep_parse (Shishi * handle, FILE * fh,
-				Shishi_asn1 * kdcrep);
 extern int shishi_ticket_parse (Shishi * handle, FILE * fh,
 				Shishi_asn1 * ticket);
 extern int shishi_ticket_read (Shishi * handle, FILE * fh,
@@ -913,6 +920,10 @@ extern int shishi_etype_info_print (Shishi * handle, FILE * fh,
 				    Shishi_asn1 etypeinfo);
 extern int shishi_etype_info2_print (Shishi * handle, FILE * fh,
 				     Shishi_asn1 etypeinfo2);
+extern int shishi_padata_print (Shishi * handle, FILE * fh,
+				Shishi_asn1 padata);
+extern int shishi_methoddata_print (Shishi * handle, FILE * fh,
+				    Shishi_asn1 methoddata);
 
 /* authenticator.c */
 extern Shishi_asn1 shishi_authenticator (Shishi * handle);
@@ -984,7 +995,7 @@ extern int
 shishi_authenticator_set_subkey (Shishi * handle,
 				 Shishi_asn1 authenticator,
 				 int32_t subkeytype,
-				 char *subkey, size_t subkeylen);
+				 const char *subkey, size_t subkeylen);
 extern int
 shishi_authenticator_add_random_subkey (Shishi * handle,
 					Shishi_asn1 authenticator);
@@ -1848,18 +1859,18 @@ extern const char *shishi_ap_option2string (Shishi_apoptions option);
 extern Shishi_apoptions shishi_ap_string2option (const char *str);
 
 /* key.c */
-extern const char *shishi_key_principal (Shishi_key * key);
+extern const char *shishi_key_principal (const Shishi_key * key);
 extern void shishi_key_principal_set (Shishi_key * key,
 				      const char *principal);
-extern const char *shishi_key_realm (Shishi_key * key);
+extern const char *shishi_key_realm (const Shishi_key * key);
 extern void shishi_key_realm_set (Shishi_key * key, const char *realm);
-extern int shishi_key_type (Shishi_key * key);
+extern int shishi_key_type (const Shishi_key * key);
 extern void shishi_key_type_set (Shishi_key * key, int32_t type);
-extern char *shishi_key_value (Shishi_key * key);
+extern const char *shishi_key_value (const Shishi_key * key);
 extern void shishi_key_value_set (Shishi_key * key, const char *value);
 extern const char *shishi_key_name (Shishi_key * key);
-extern size_t shishi_key_length (Shishi_key * key);
-extern uint32_t shishi_key_version (Shishi_key * key);
+extern size_t shishi_key_length (const Shishi_key * key);
+extern uint32_t shishi_key_version (const Shishi_key * key);
 extern void shishi_key_version_set (Shishi_key * key, uint32_t kvno);
 extern int shishi_key (Shishi * handle, Shishi_key ** key);
 extern void shishi_key_done (Shishi_key * key);
@@ -2214,7 +2225,6 @@ extern char *shishi_x509ca_default_file_guess (Shishi * handle);
 extern void shishi_x509ca_default_file_set (Shishi * handle,
 					    const char *x509cafile);
 extern const char *shishi_x509ca_default_file (Shishi * handle);
-extern char *shishi_x509ca_default_file_guess (Shishi * handle);
 extern char *shishi_x509cert_default_file_guess (Shishi * handle);
 extern void shishi_x509cert_default_file_set (Shishi * handle,
 					      const char *x509certfile);
@@ -2226,10 +2236,19 @@ extern const char *shishi_x509key_default_file (Shishi * handle);
 
 /* utils.c */
 extern time_t shishi_get_date (const char *p, const time_t * now);
-extern void shishi_xalloc_die (void);
+/* Ugly hack to avoid re-declaring shishi_xalloc_die twice.  It is
+   already declared in xalloc.h internally in Shishi.h.  This is to
+   keep being able to use -Wredundant-decls. */
+#if defined(SYSTEMCFGFILE) && !defined(XALLOC_H_)
+extern void shishi_xalloc_die (void) __attribute__ ((__noreturn__));
+#endif
 
 /* resolv.c */
 extern Shishi_dns shishi_resolv (const char *zone, uint16_t querytype);
 extern void shishi_resolv_free (Shishi_dns rrs);
 
+# ifdef __cplusplus
+}
+# endif
+
 #endif
