@@ -30,8 +30,8 @@
  * @handle: Shishi library handle create by shishi_init().
  *
  * Guesses the default ccache ticket filename; it is the contents of
- * the environment variable KRB5CCNAME or /tmp/krb5cc_<UID> where
- * <UID> is the user's identity in decimal, as returned by getuid().
+ * the environment variable KRB5CCNAME or /tmp/krb5cc_UID where UID is
+ * the user's identity in decimal, as returned by getuid().
  *
  * Return value: Returns default ccache filename as a string that has
  *   to be deallocated with free() by the caller.
@@ -426,6 +426,7 @@ shishi_tkts_from_ccache_file (Shishi * handle,
   return SHISHI_OK;
 }
 
+#if 0
 int
 shishi_tkt_to_ccache_mem (Shishi *handle,
 			  Shishi_tkt *tkt,
@@ -460,6 +461,8 @@ shishi_tkt_to_ccache_mem (Shishi *handle,
   if (rc != SHISHI_OK)
     return rc;
 
+  return SHISHI_OK;
+
 #if 0
   {
 	char *cname[CCACHE_MAX_COMPONENTS + 1];
@@ -582,6 +585,9 @@ shishi_tkts_to_ccache_mem (Shishi *handle,
 			   Shishi_tkts *tkts,
 			   char **data, size_t *len)
 {
+  return SHISHI_CCACHE_ERROR;
+
+#if 0
   struct ccache info;
   int rc = SHISHI_OK;
   size_t i;
@@ -600,12 +606,12 @@ shishi_tkts_to_ccache_mem (Shishi *handle,
       printf ("f %d\n", rc);
     }
 
-#if 0
   memset (&info, 0, sizeof (info));
 
   rc = ccache_pack (&info, *data, *len);
   printf ("pack res %d len %d\n", rc, *len);
-#endif
 
   return rc;
+#endif
 }
+#endif
