@@ -34,8 +34,6 @@
 #include <locale.h>
 #include <gettext.h>
 #define _(String) gettext (String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
 
 /* Gnulib helpers. */
 #include "xvasprintf.h"
@@ -401,7 +399,7 @@ apply_options (const char *realm,
       dbkey->kvno = args.key_version_arg;
       dbkey->etype = etype;
       dbkey->priority = args.priority_arg;
-      dbkey->key = shishi_key_value (key);
+      dbkey->key = (char*) shishi_key_value (key);
       dbkey->keylen = shishi_key_length (key);
       dbkey->salt = salt;
       dbkey->saltlen = salt ? strlen (salt) : 0;
@@ -417,6 +415,9 @@ const char version_etc_copyright[] =
      year.  */
   "Copyright %s %d Simon Josefsson.";
 
+static void
+usage (int status) __attribute__ ((__noreturn__));
+
 static void
 usage (int status)
 {
